@@ -15,7 +15,7 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/Glib.pm,v 1.45.2.5 2004/02/06 02:11:07 muppetman Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/Glib.pm,v 1.52 2004/01/30 01:03:47 rwmcfa1 Exp $
 #
 
 package Glib;
@@ -23,22 +23,43 @@ package Glib;
 use 5.008;
 use strict;
 use warnings;
-
+use Exporter;
 require DynaLoader;
-our @ISA = qw(DynaLoader);
+our @ISA = qw(DynaLoader Exporter);
 
-our $VERSION = '1.022';
+use constant {
+	TRUE  => 1,
+	FALSE => !1, # can't use !TRUE at this point
+	G_PRIORITY_HIGH         => -100,
+	G_PRIORITY_DEFAULT      =>  0,
+	G_PRIORITY_HIGH_IDLE    =>  100,
+	G_PRIORITY_DEFAULT_IDLE =>  200,
+	G_PRIORITY_LOW	        =>  300,
+};
 
-# this is the 'lite' version of what we could get Exporter to do for us.
-# we export nothing, so it seems silly to drag in all of Exporter::Heavy
-# just for a version check.
-sub import {
-	my $pkg = shift;
-	foreach (@_) {
-		no strict;
-		$pkg->VERSION ($_);
-	}
-}
+# export nothing by default.
+# export functions and constants by request.
+our %EXPORT_TAGS = (
+	constants => [qw/
+			TRUE
+			FALSE
+			G_PRIORITY_HIGH
+			G_PRIORITY_DEFAULT
+			G_PRIORITY_HIGH_IDLE
+			G_PRIORITY_DEFAULT_IDLE
+			G_PRIORITY_LOW
+			/],
+	functions => [qw/
+			filename_to_unicode
+			filename_from_unicode
+			filename_to_uri
+			filename_from_uri
+			/],
+);
+our @EXPORT_OK = map { @$_ } values %EXPORT_TAGS;
+$EXPORT_TAGS{all} = \@EXPORT_OK;
+
+our $VERSION = '1.033';
 
 sub dl_load_flags { $^O eq 'darwin' ? 0x00 : 0x01 }
 
@@ -306,9 +327,15 @@ to manage filenames returned by a GLib/Gtk+ function, or when you feed
 filenames into GLib/Gtk+ functions that have their source outside your
 program (e.g. commandline arguments, readdir results etc.).
 
+These functions are available as exports by request (see L</Exports>),
+and also support method invocation syntax for pathological consistency
+with the OO syntax of the rest of the bindings.
+
 =over 4
 
-=item $filename = Glib::filename_to_unicode $filename_in_local_encoding
+=item $filename = filename_to_unicode $filename_in_local_encoding
+
+=item $filename = Glib->filename_to_unicode ($filename_in_local_encoding)
 
 Convert a perl string that supposedly contains a filename in local
 encoding into a filename represented as unicode, the same way that GLib
@@ -316,16 +343,18 @@ does it internally.
 
 Example:
 
-   $gtkfilesel->set_filename (Glib::filename_to_unicode $ARGV[1]);
+   $gtkfilesel->set_filename (filename_to_unicode $ARGV[1]);
 
-=item $filename_in_local_encoding = Glib::filename_from_unicode $filename
+=item $filename_in_local_encoding = filename_from_unicode $filename
+
+=item $filename_in_local_encoding = Glib->filename_from_unicode ($filename)
 
 Converts a perl string containing a filename into a filename in the local
 encoding in the same way GLib does it.
 
 Example:
 
-   open MY, "<", Glib::filename_from_unicode $gtkfilesel->get_filename;
+   open MY, "<", filename_from_unicode $gtkfilesel->get_filename;
 
 =back
 
@@ -384,6 +413,33 @@ these messages through Perl's native system, warn() and die().  Extensions
 should register the log domains they wrap for this to happen fluidly.
 [FIXME say more here]
 
+=head1 Exports
+
+For the most part, gtk2-perl avoids exporting things.  Nothing is exported by
+default, but some functions and constants in Glib are available by request;
+you can also get all of them with the export tag "all".
+
+=over
+
+=item Tag: constants
+
+  TRUE
+  FALSE
+  G_PRIORITY_HIGH
+  G_PRIORITY_DEFAULT
+  G_PRIORITY_HIGH_IDLE
+  G_PRIORITY_DEFAULT_IDLE
+  G_PRIORITY_LOW
+
+=item Tag: functions
+
+  filename_from_unicode
+  filename_to_unicode
+  filename_from_uri
+  filename_to_uri
+
+=back
+
 =head1 SEE ALSO
 
 L<Glib::Object::Subclass> explains how to create your own gobject subclasses
