@@ -15,11 +15,13 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/Subclass.pm,v 1.5 2003/09/21 16:59:12 rwmcfa1 Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/Subclass.pm,v 1.7 2003/12/30 16:46:22 rwmcfa1 Exp $
 #
 
 package Glib::Object::Subclass;
 
+our $VERSION = '0.01';
+
 use Glib;
 
 =head1 NAME
@@ -228,9 +230,8 @@ sub import {
 
 To create gobject properties, supply a list of Glib::ParamSpec objects as the
 value for the key 'properties'.  There are lots of different paramspec
-constructors, documented in the C API reference's Parameters and Values page.
-
-TODO:  put a list here with the proper perl syntax for each
+constructors, documented in the C API reference's Parameters and Values page,
+as well as L<Glib::ParamSpec>.
 
 =head1 SIGNALS
 
@@ -243,11 +244,11 @@ keys are allowed to default.
 
 =item flags => GSignalFlags
 
-If not present, assumed to be run-first
+If not present, assumed to be 'run-first'.
 
 =item param_types => reference to a list of package names
 
-If not present, assumed to be empty (no parameters)
+If not present, assumed to be empty (no parameters).
 
 =item class_closure => reference to a subroutine to call as the class closure.
 
